@@ -2,18 +2,33 @@
 
 #    Copyright 2009, Brent Chiodo
 
-#    This program is free software: you can redistribute it and/or modify
-#    it under the terms of the GNU General Public License as published by
-#    the Free Software Foundation, either version 3 of the License, or
-#    (at your option) any later version.
-#
-#    This program is distributed in the hope that it will be useful,
-#    but WITHOUT ANY WARRANTY; without even the implied warranty of
-#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-#    GNU General Public License for more details.
+#      IMPORTANT, PLEASE READ CAREFULLY. THIS IS A LICENSE AGREEMENT
 
-#    You should have received a copy of the GNU General Public License
-#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
+#      This SOFTWARE PRODUCT is protected by copyright laws and international copyright treaties, as well as other intellectual property laws and treaties. This SOFTWARE PRODUCT is licensed, not sold.
+
+#      End User License Agreement
+
+#      This End User License Agreement ("EULA") is a legal agreement between you (either an individual or a single entity) and Brent Chiodo with regard to the copyrighted Software (herein referred to as "SOFTWARE PRODUCT" or "SOFTWARE") provided with this EULA.  The SOFTWARE PRODUCT includes computer software, the associated media, any printed materials, and any "online" or electronic documentation. Use of any software and related documentation ("Software") provided to you by Brent Chiodo in whatever form or media, will constitute your acceptance of these terms, unless separate terms are provided by the software supplier, in which case certain additional or different terms may apply. If you do not agree with the terms of this EULA, do not download, install, copy or use the Software. By installing, copying or otherwise using the SOFTWARE PRODUCT, you agree to be bound by the terms of this EULA.
+
+#      1.  Eligible Licensees. This Software is available for license solely to SOFTWARE owners, with no right of duplication or further distribution, licensing, or sub-licensing.  IF YOU DO NOT OWN THE SOFTWARE, THEN DO NOT DOWNLOAD, INSTALL, COPY OR USE THE SOFTWARE.
+
+#      2.  License Grant.  Brent Chiodo grants to you a personal, non-transferable and non-exclusive right to use the copy of the Software provided with this EULA. You agree you will not copy the Software except as necessary to use it on a single computer. You agree that you may not copy the written materials accompanying the Software. Modifying, translating, renting, copying, transferring or assigning all or part of the Software, or any rights granted hereunder, to any other persons and removing any proprietary notices, labels or marks from the Software is strictly prohibited.  Furthermore, you hereby agree not to create derivative works based on the Software.  You may not transfer this Software.
+
+#      3.  Copyright.  The Software is licensed, not sold.  You acknowledge that no title to the intellectual property in the Software is transferred to you. You further acknowledge that title and full ownership rights to the Software will remain the exclusive property of Brent Chiodo and/or its suppliers, and you will not acquire any rights to the Software, except as expressly set forth above. All copies of the Software will contain the same proprietary notices as contained in or on the Software. All title and copyrights in and to the SOFTWARE PRODUCT (including but not limited to any images, photographs, animations, video, audio, music, text and "applets," incorporated into the SOFTWARE PRODUCT), the accompanying printed materials, and any copies of the SOFTWARE PRODUCT, are owned by Brent Chiodo or its suppliers.  The SOFTWARE PRODUCT is protected by copyright laws and international treaty provisions.  You may not copy the printed materials accompanying the SOFTWARE PRODUCT.
+
+#      4.  Reverse Engineering.  You agree that you will not attempt, and if you are a corporation, you will use your best efforts to prevent your employees and contractors from attempting to reverse compile, modify, translate or disassemble the Software in whole or in part. Any failure to comply with the above or any other terms and conditions contained herein will result in the automatic termination of this license and the reversion of the rights granted hereunder to Brent Chiodo.
+
+#      5.  Disclaimer of Warranty. The Software is provided "AS IS" without warranty of any kind. Brent Chiodo and its suppliers disclaim and make no express or implied warranties and specifically disclaim the warranties of merchantability, fitness for a particular purpose and non-infringement of third-party rights. The entire risk as to the quality and performance of the Software is with you. Neither Brent Chiodo nor its suppliers warrant that the functions contained in the Software will meet your requirements or that the operation of the Software will be uninterrupted or error-free. Brent Chiodo IS NOT OBLIGATED TO PROVIDE ANY UPDATES TO THE SOFTWARE.
+
+#      6.  Limitation of Liability. Brent Chiodo's entire liability and your exclusive remedy under this EULA shall not exceed the price paid for the Software, if any.  In no event shall Brent Chiodo or its suppliers be liable to you for any consequential, special, incidental or indirect damages of any kind arising out of the use or inability to use the software, even if Brent Chiodo or its supplier has been advised of the possibility of such damages, or any claim by a third party. 
+
+#      7.  Rental.  You may not loan, rent, or lease the SOFTWARE. 
+
+#      8.  Upgrades.  If the SOFTWARE is an upgrade from an earlier release or previously released version, you now may use that upgraded product only in accordance with this EULA.  If the SOFTWARE PRODUCT is an upgrade of a software program which you licensed as a single product, the SOFTWARE PRODUCT may be used only as part of that single product package and may not be separated for use on more than one computer.
+
+#      9.  No Liability for Consequential Damages.  In no event shall Brent Chiodo or its suppliers be liable for any damages whatsoever (including, without limitation, incidental, direct, indirect special and consequential damages, damages for loss of business profits, business interruption, loss of business information, or other pecuniary loss) arising out of the use or inability to use this product. Because some states/countries do not allow the exclusion or limitation of liability for consequential or incidental damages, the above limitation may not apply to you.
+
+#      10.  Indemnification By You.  If you distribute the Software in violation of this Agreement, you agree to indemnify, hold harmless and defend Brent Chiodo and its suppliers from and against any claims or lawsuits, including attorney's fees that arise or result from the use or distribution of the Software in violation of this Agreement.
 
 
 import gobject
@@ -387,19 +402,34 @@ class TouchSearchHomePlugin(hildondesktop.HomePluginItem):
       dialog.set_authors(["Brent Chiodo <bchiodo@gmail.com>"])
       dialog.set_logo(gtk.gdk.pixbuf_new_from_file("/usr/share/touchsearch/icon.png"))
       dialog.set_comments("All logos and trademarks are property of their respective owners and are used for informational purposes only.")
-      dialog.set_license("""This program is free software: you can redistribute it and/or
-modify it under the terms of the GNU General Public License as 
-published by the Free Software Foundation, either version 3 of
-the License, or (at your option) any later version.
+      dialog.set_license("""IMPORTANT, PLEASE READ CAREFULLY. THIS IS A LICENSE AGREEMENT
 
-This program is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied 
-warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-PURPOSE.  See the GNU General Public License for more details.
+This SOFTWARE PRODUCT is protected by copyright laws and international copyright treaties, as well as other intellectual property laws and treaties. This SOFTWARE PRODUCT is licensed, not sold.
 
-You should have received a copy of the GNU General Public 
-License along with this program.  If not, see
-<http://www.gnu.org/licenses/>.""")
+End User License Agreement
+
+This End User License Agreement ("EULA") is a legal agreement between you (either an individual or a single entity) and Brent Chiodo with regard to the copyrighted Software (herein referred to as "SOFTWARE PRODUCT" or "SOFTWARE") provided with this EULA.  The SOFTWARE PRODUCT includes computer software, the associated media, any printed materials, and any "online" or electronic documentation. Use of any software and related documentation ("Software") provided to you by Brent Chiodo in whatever form or media, will constitute your acceptance of these terms, unless separate terms are provided by the software supplier, in which case certain additional or different terms may apply. If you do not agree with the terms of this EULA, do not download, install, copy or use the Software. By installing, copying or otherwise using the SOFTWARE PRODUCT, you agree to be bound by the terms of this EULA.
+
+1.  Eligible Licensees. This Software is available for license solely to SOFTWARE owners, with no right of duplication or further distribution, licensing, or sub-licensing.  IF YOU DO NOT OWN THE SOFTWARE, THEN DO NOT DOWNLOAD, INSTALL, COPY OR USE THE SOFTWARE.
+
+2.  License Grant.  Brent Chiodo grants to you a personal, non-transferable and non-exclusive right to use the copy of the Software provided with this EULA. You agree you will not copy the Software except as necessary to use it on a single computer. You agree that you may not copy the written materials accompanying the Software. Modifying, translating, renting, copying, transferring or assigning all or part of the Software, or any rights granted hereunder, to any other persons and removing any proprietary notices, labels or marks from the Software is strictly prohibited.  Furthermore, you hereby agree not to create derivative works based on the Software.  You may not transfer this Software.
+
+3.  Copyright.  The Software is licensed, not sold.  You acknowledge that no title to the intellectual property in the Software is transferred to you. You further acknowledge that title and full ownership rights to the Software will remain the exclusive property of Brent Chiodo and/or its suppliers, and you will not acquire any rights to the Software, except as expressly set forth above. All copies of the Software will contain the same proprietary notices as contained in or on the Software. All title and copyrights in and to the SOFTWARE PRODUCT (including but not limited to any images, photographs, animations, video, audio, music, text and "applets," incorporated into the SOFTWARE PRODUCT), the accompanying printed materials, and any copies of the SOFTWARE PRODUCT, are owned by Brent Chiodo or its suppliers.  The SOFTWARE PRODUCT is protected by copyright laws and international treaty provisions.  You may not copy the printed materials accompanying the SOFTWARE PRODUCT.
+
+4.  Reverse Engineering.  You agree that you will not attempt, and if you are a corporation, you will use your best efforts to prevent your employees and contractors from attempting to reverse compile, modify, translate or disassemble the Software in whole or in part. Any failure to comply with the above or any other terms and conditions contained herein will result in the automatic termination of this license and the reversion of the rights granted hereunder to Brent Chiodo.
+
+5.  Disclaimer of Warranty. The Software is provided "AS IS" without warranty of any kind. Brent Chiodo and its suppliers disclaim and make no express or implied warranties and specifically disclaim the warranties of merchantability, fitness for a particular purpose and non-infringement of third-party rights. The entire risk as to the quality and performance of the Software is with you. Neither Brent Chiodo nor its suppliers warrant that the functions contained in the Software will meet your requirements or that the operation of the Software will be uninterrupted or error-free. Brent Chiodo IS NOT OBLIGATED TO PROVIDE ANY UPDATES TO THE SOFTWARE.
+
+6.  Limitation of Liability. Brent Chiodo's entire liability and your exclusive remedy under this EULA shall not exceed the price paid for the Software, if any.  In no event shall Brent Chiodo or its suppliers be liable to you for any consequential, special, incidental or indirect damages of any kind arising out of the use or inability to use the software, even if Brent Chiodo or its supplier has been advised of the possibility of such damages, or any claim by a third party. 
+
+7.  Rental.  You may not loan, rent, or lease the SOFTWARE. 
+
+8.  Upgrades.  If the SOFTWARE is an upgrade from an earlier release or previously released version, you now may use that upgraded product only in accordance with this EULA.  If the SOFTWARE PRODUCT is an upgrade of a software program which you licensed as a single product, the SOFTWARE PRODUCT may be used only as part of that single product package and may not be separated for use on more than one computer.
+
+9.  No Liability for Consequential Damages.  In no event shall Brent Chiodo or its suppliers be liable for any damages whatsoever (including, without limitation, incidental, direct, indirect special and consequential damages, damages for loss of business profits, business interruption, loss of business information, or other pecuniary loss) arising out of the use or inability to use this product. Because some states/countries do not allow the exclusion or limitation of liability for consequential or incidental damages, the above limitation may not apply to you.
+
+10.  Indemnification By You.  If you distribute the Software in violation of this Agreement, you agree to indemnify, hold harmless and defend Brent Chiodo and its suppliers from and against any claims or lawsuits, including attorney's fees that arise or result from the use or distribution of the Software in violation of this Agreement.""")
+      dialog.set_wrap_license(True)
       dialog.show_all()
       dialog.run()
       dialog.destroy()
@@ -725,15 +755,15 @@ License along with this program.  If not, see
          return True
       
    def ok_button_callback(self, widget, name_entry, url_entry, file_button, engine):
+      model, treeiter, engine = self.get_treeview_data()
       name = name_entry.get_text()
       url = url_entry.get_text()
       icon = file_button.get_value()
       
-      self.model[self.treeiter][0] = name
-      index = self.search_engines.index(engine)
-      self.search_engines[index]['name'] = name
-      self.search_engines[index]['url'] = url
-      self.search_engines[index]['icon'] = icon
+      self.liststore[treeiter][0] = name
+      self.search_engines[engine]['name'] = name
+      self.search_engines[engine]['url'] = url
+      self.search_engines[engine]['icon'] = icon
       
       SearchEngines().write(self.search_engines)
          
